<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE" sourcelanguage="en">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Move</source>
        <translation>Verschieben</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Share</source>
        <translation>Freigeben</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Change icon</source>
        <translation>Ändern Sie das Symbol</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Compress</source>
        <translation>Komprimieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Documents</source>
        <translation>Dokumente</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Images</source>
        <translation>Fotos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Camera</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Sounds</source>
        <translation>Töne</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Videos</source>
        <translation>Videos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Added to Clipboard</source>
        <translation>In Zwischenablage kopieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>ERROR: Nothing selected to paste</source>
        <translation>FEHLER: Nichts zum Einfügen markiert</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Cannot create symlink in this folder</source>
        <translation>Verknüpfung kann in diesem Ordner nicht erstellt werden</translation>
    </message>
    <message>
        <location filename="../error.cpp" line="10"/>
        <source>Not enough space to proceed.</source>
        <translation>Nicht genug Platz zum Fortsetzen.</translation>
    </message>
    <message>
        <location filename="../error.cpp" line="10"/>
        <source>You don&apos;t have permissions to proceed.</source>
        <translation>Sie haben keine Berechtigung zum Fortsetzen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>About</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Broken Symlink!</source>
        <translation>Defekter symbolischer Link!</translation>
    </message>
</context>
<context>
    <name>BookWindow</name>
    <message>
        <location filename="../bookwindow.cpp" line="10"/>
        <source>Bookmarks</source>
        <translation>Lesezeichen</translation>
    </message>
</context>
<context>
    <name>Home</name>
    <message>
        <location filename="../home.cpp" line="10"/>
        <source>Home folder</source>
        <translation>Arbeitsplatz</translation>
    </message>
    <message>
        <location filename="../home.cpp" line="10"/>
        <source>Compress destination</source>
        <translation>Zief für die Komprimierung</translation>
    </message>
    <message>
        <location filename="../home.cpp" line="10"/>
        <source>Extract destination</source>
        <translation>Ziel für die Dekomprimierung</translation>
    </message>
    <message>
        <location filename="../home.cpp" line="10"/>
        <source>Symlink destination</source>
        <translation>Ziel der Verknüpfung</translation>
    </message>
</context>
<context>
    <name>Clipboard</name>
    <message>
        <location filename="../clipboard.cpp" line="10"/>
        <source>Clipboard</source>
        <translation>Zwischenablage</translation>
    </message>
</context>
<context>
    <name>Bookmarks</name>
    <message>
        <location filename="../bookmarks.cpp" line="10"/>
        <source>Bookmarks</source>
        <translation>Lesezeichen</translation>
    </message>
    <message>
        <location filename="../bookmarks.cpp" line="10"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../bookmarks.cpp" line="10"/>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
</context>
<context>
    <name>ToolsDialog</name>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Tools</source>
        <translation>Werkzeuge</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Add to Bookmarks</source>
        <translation>Zu Lesezeichen hinzufügen</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Create new folder</source>
        <translation>Neuen Ordner Erstellen</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Create new document</source>
        <translation>Neues Dokument erstellen</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Open terminal here</source>
        <translation>Terminal hier öffnen</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Create new symlink</source>
        <translation>Neue Verknüpfung erstellen</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Sort</source>
        <translation>Sortieren</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Paste from clipboard</source>
        <translation>Einfügen aus Zwischenablage</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Cut from clipboard</source>
        <translation>Aus Zwischenablage ausschneiden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>ERROR: Nothing selected to paste</source>
        <translation>FEHLER: Nichts zum einfügen ausgewählt</translation>
    </message>
</context>
<context>
    <name>Share</name>
    <message>
        <location filename="../share.cpp" line="10"/>
        <source>Share</source>
        <translation>Freigeben</translation>
    </message>
    <message>
        <location filename="../share.cpp" line="10"/>
        <source>Send via bluetooth</source>
        <translation>Über Bluetooth senden</translation>
    </message>
    <message>
        <location filename="../share.cpp" line="10"/>
        <source>Send via e-mail</source>
        <translation>Per E-Mail senden</translation>
    </message>
</context>
<context>
    <name>QtCopyDialog</name>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>%1 of %2 completed</source>
        <translation>%1 von %2 erledigt</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Copy Warning</source>
        <translation>Kopierwarnung</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source doesn&apos;t exist.</source>
        <translation>Quelle existiert nicht.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>No enough space for copy the file.</source>
        <translation>Nicht genug Platz zum kopieren der Datei.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source file is a directory. Omitting source directory.</source>
        <translation>Ursprungsdatei ist ein Ordner und wird ausgelassen.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source directory is a file. Omitting source file.</source>
        <translation>Ursprungsordner ist eine Datei und wird ausgelassen.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Path to destination does not exist.</source>
        <translation>Pfad zum Ziel existiert nicht.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot create destination directory.</source>
        <translation>Kann Zielordner nicht erstellen.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot open source file. Please check permissions.</source>
        <translation>Kann Quellldatei nicht öffnen. Bitte Berechtigungen überprüfen.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot open destination file. Please check permissions.</source>
        <translation>Kann Zieldatei nicht öffnen. Bitte Berechtigungen überprüfen.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Force: Cannot remove destination file.</source>
        <translation>Kann Zieldatei nicht entfernen.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot create symbolic link targeting to source.</source>
        <translation>Kann keinen symbolischen Link zur Quelle erstellen.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot read source file.</source>
        <translation>Kann Quelldatei nicht lesen.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot write destination file.</source>
        <translation>Kann Zieldatei nicht schreiben.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot remove source.</source>
        <translation>Kann Quellei nicht löschen.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>100% of %1 (Done)</source>
        <translation>100% von %1 (Fertig)</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Copying...</source>
        <translation>Kopiere...</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>%1% of %2 (%3)</source>
        <translation>%1% von %2 (%3)</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source</source>
        <translation>Quelle</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Destination</source>
        <translation>Ziel</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
<context>
    <name>QtOverwriteDialog</name>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Copy Warning</source>
        <translation>Kopierwarnung</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source</source>
        <translation>Quelle</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Destination</source>
        <translation>Ziel</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Skip</source>
        <translation>Überspringen</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Overwrite</source>
        <translation>Überschreiben</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Destination already exists.</source>
        <translation>Ziel existiert bereits.</translation>
    </message>
</context>
<context>
    <name>DeleteDialog</name>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Preparing to delete %1 files</source>
        <translation>Bereite das Löschen von %1 Dateien vor</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Deleting %1</source>
        <translation>Lösche %1</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Error deleting %1</source>
        <translation>Fehler beim löschen von %1</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Delete Finished Ok</source>
        <translation>Löschvorgang beendet</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Abort</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Deleting files</source>
        <translation>Lösche Dateien</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Apply</source>
        <translation>Zuweisen</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Home folder</source>
        <translation>Arbeitsplatz</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Icons Style</source>
        <translation>Stil der Symbole</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Text Editor</source>
        <translation>Texteditor</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Enable root access (restart needed)</source>
        <translation>&apos;Root&apos;- Zugriff aktivieren (benötigt Neustart)</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Show hidden files and folders</source>
        <translation>Versteckte Ordner und Dateien anzeigen</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Show thumbnails for images</source>
        <translation>Miniaturansicht für Bilder anzeigen</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Show details for files</source>
        <translation>Dateieigenschaften anzeigen</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Delete items from clipboard on Paste</source>
        <translation>Nach dem Einfügen Zwischenablage löschen</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Enable multiselection</source>
        <translation>Mehrfachselektion aktivieren</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Auto select items in clipboard</source>
        <translation>Objekte in Zwischenablage automatisch auswählen</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Orientation</source>
        <translation>Orientierung</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Automatic</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Portrait</source>
        <translation>Hochformat</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Landscape</source>
        <translation>Querformat</translation>
    </message>
</context>
<context>
    <name>NewFolder</name>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Create folder</source>
        <translation>Erstelle Ordner</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Enter new folder name</source>
        <translation>Neuen Ordnernamen eingeben</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Accept</source>
        <translation>Akzeptieren</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Cannot create folder. Try another name.</source>
        <translation>Kann Ordner nicht erstellen. Name vergeben.</translation>
    </message>
</context>
<context>
    <name>QtOtherDialog</name>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Retry</source>
        <translation>Wiederholen</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Skip</source>
        <translation>Überspringen</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source</source>
        <translation>Quelle</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Destination</source>
        <translation>Ziel</translation>
    </message>
</context>
<context>
    <name>Rename</name>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Renaming</source>
        <translation>Neubenennung</translation>
    </message>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Enter new name</source>
        <translation>Neuen Namen eingeben</translation>
    </message>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Accept</source>
        <translation>Akzeptieren</translation>
    </message>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Cannot rename. Try another name.</source>
        <translation>Umbennenen fehlgeschlagen. Name vergeben.</translation>
    </message>
</context>
<context>
    <name>AskDialog</name>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>Deleting</source>
        <translation>Löschvorgang</translation>
    </message>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>Sicher, dass Sie %1 löschen wollen?</translation>
    </message>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>Are you sure you want to delete selected files?</source>
        <translation>Sicher, dass Sie die markierten Dateien löschen wollen?</translation>
    </message>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>No</source>
        <translation>Nein</translation>
    </message>
</context>
<context>
    <name>Sort</name>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Sort</source>
        <translation>Sortieren</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Ascending</source>
        <translation>aufsteigend</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Descending</source>
        <translation>absteigend</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Name (A-Z)</source>
        <translation>Name (A-Z)</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Name (Z-A)</source>
        <translation>Name (Z-A)</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Date (olders first)</source>
        <translation>Datum (älteste zuerst)</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Date (recents first)</source>
        <translation>Datum (neuste zuerst)</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Size (smallers first)</source>
        <translation>Grösse (kleinste zuerst)</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Size (biggers first)</source>
        <translation>Grösse (grösste zuerst)</translation>
    </message>
</context>
<context>
    <name>NewDoc</name>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>New document</source>
        <translation>Neues Dokument</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Create</source>
        <translation>Erstellen</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Enter name for new document</source>
        <translation>Geben Sie einen Namen für das neue Dokument ein</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Enter a valid file name</source>
        <translation>Geben Sie einen gültigen Dateinamen ein</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>The file already exists. Try another name</source>
        <translation>Die Datei ist bereits vorhanden. Name vergeben</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Cannot create the file. Check permissions</source>
        <translation>Datei kann nicht erstellt werden. Berechtigungen überprüfen</translation>
    </message>
</context>
<context>
    <name>Error</name>
    <message>
        <location filename="../error.cpp" line="10"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../error.cpp" line="10"/>
        <source>Accept</source>
        <translation>Akzeptieren</translation>
    </message>
</context>
<context>
    <name>CompressDlg</name>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Compress</source>
        <translation>Komprimieren</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>File name</source>
        <translation>Dateiname</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Compression</source>
        <translation>Komprimierung</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Destination folder</source>
        <translation>Zielordner</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Accept</source>
        <translation>Akzeptieren</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>The file already exists. Try another name.</source>
        <translation>Die Datei existiert bereits. Name vergeben.</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Not enough space to proceed.</source>
        <translation>Nicht genug Platz zum Fortsetzen.</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>You don&apos;t have permissions to proceed.</source>
        <translation>Sie haben keine Berechtigung zum Fortsetzen.</translation>
    </message>
</context>
<context>
    <name>Compress</name>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Compressing</source>
        <translation>Komprimiere</translation>
    </message>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Adding %1...</source>
        <translation>Einfügen von %1...</translation>
    </message>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Operation finished.</source>
        <translation>Aufgabe abgeschloßen.</translation>
    </message>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
<context>
    <name>Unzip</name>
    <message>
        <location filename="../unzip.cpp" line="10"/>
        <source>Extract files</source>
        <translation>Extrahiere Dateien</translation>
    </message>
    <message>
        <location filename="../unzip.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../unzip.cpp" line="10"/>
        <source>Not enough space to proceed.</source>
        <translation>Nicht genug Platz zum Fortsetzen.</translation>
    </message>
    <message>
        <location filename="../unzip.cpp" line="10"/>
        <source>You don&apos;t have permissions to proceed.</source>
        <translation>Keine Berechtigung zum Fortsetzen.</translation>
    </message>
</context>
<context>
    <name>UnzipDlg</name>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Extract</source>
        <translation>Extrahiere</translation>
    </message>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Destination folder</source>
        <translation>Zielverzeichnis</translation>
    </message>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Keep existing files</source>
        <translation>Existierende Dateien behalten</translation>
    </message>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Accept</source>
        <translation>Akzeptieren</translation>
    </message>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Password</source>
        <translation>Kennwort</translation>
    </message>
</context>
<context>
    <name>Extract</name>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Extracting</source>
        <translation>Extrahiere</translation>
    </message>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Extracting %1...</source>
        <translation>Extrahiere %1...</translation>
    </message>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Operation finished.</source>
        <translation>Aufgabe abgeschloßen.</translation>
    </message>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Error extracting files. Incorrect password?</source>
        <translation>Fehler beim Extrahieren. Falsches Passwort?</translation>
    </message>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
<context>
    <name>About</name>
    <message>
        <location filename="../about.cpp" line="10"/>
        <source>About FileBox</source>
        <translation>Über FileBox</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="10"/>
        <source>File Manager for Maemo 5</source>
        <translation>Dateimanager für Maemo 5</translation>
    </message>
</context>
<context>
    <name>selectIcon</name>
    <message>
        <location filename="../selecticon.cpp" line="10"/>
        <source>Select icon</source>
        <translation>Wählen Sie das Symbol</translation>
    </message>
</context>
</TS>
